@@ -9,12 +9,16 @@ reqs = parse_requirements('NLP_LIB/requirements-cpu.txt')
 
 print(reqs)
 
+print("==== PACKAGE DATA ====")
+package_data = list(map(lambda x: x[8:], glob('NLP_LIB/*.json')))
+print(package_data)
+
 with open("NLP_LIB/README.md", "r") as fh:
   long_description = fh.read()
 
 setup(
   name="NLP_LIB_cpu", # Replace with your own username
-  version="0.0.5",
+  version="0.0.8",
   author="Chulayuth Asawaroengchai",
   author_email="twilightdema@gmail.com",
   description="Python library for Language Model / Finetune using Transformer based models.",
@@ -23,7 +27,7 @@ setup(
   url="https://github.com/twilightdema/NLP_LIB.git",
   packages=find_packages(),
   package_data={
-    'NLP_LIB': map(lambda x: x[8:], glob('NLP_LIB/*.json')),
+    'NLP_LIB': package_data,
   },
   classifiers=[
     "Programming Language :: Python :: 3",
@@ -32,4 +36,4 @@ setup(
   ],
   install_requires=reqs,
   python_requires='>=3.6',
-)
\ No newline at end of file
+)
